==> haskell-word-wrap-0.5-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 word-wrap
version:              0.5
visibility:           public
id:                   word-wrap-0.5-JdnTSx9C4A0EHhYTdZfyhi
key:                  word-wrap-0.5-JdnTSx9C4A0EHhYTdZfyhi
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  0933f0828098a32d5951c9d7a7ea20e1
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-word-wrap
hs-libraries:         HSword-wrap-0.5-JdnTSx9C4A0EHhYTdZfyhi
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-word-wrap-0.5-193-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-word-wrap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 word-wrap
version:              0.5
visibility:           public
id:                   word-wrap-0.5-8zppaZLVrOiGvyFcpEoK7m
key:                  word-wrap-0.5-8zppaZLVrOiGvyFcpEoK7m
license:              BSD-3-Clause
copyright:            2017 Jonathan Daugherty
maintainer:           cygnus@foobox.com
author:               Jonathan Daugherty
homepage:             https://github.com/jtdaugherty/word-wrap/
synopsis:             A library for word-wrapping
description:          A library for wrapping long lines of text.
category:             Text
abi:                  7f48fa30dba018d2e717068c846ea4f4
exposed:              True
exposed-modules:      Text.Wrap
import-dirs:          /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/word-wrap-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-word-wrap
hs-libraries:         HSword-wrap-0.5-8zppaZLVrOiGvyFcpEoK7m
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-word-wrap/html/word-wrap.haddock
haddock-html:         /usr/share/doc/haskell-word-wrap/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
